## Comic publishers

### Variables

- publisher = name of the publisher
- yr_founded = year the publisher was founded

<a href="http://stat545-ubc.github.io/bit001_dplyr-cheatsheet.html" target="_blank">Source</a>
